//
//  ArrowView.swift
//  GesturePlayground
//
//  Created by Holger Hinzberg on 25.01.16.
//  Copyright © 2016 Holger Hinzberg. All rights reserved.
//

import UIKit

class ArrowView: UIView, UIGestureRecognizerDelegate
{
    override init(frame: CGRect)
    {
        super.init(frame: frame)
        // Ein transparenter Hintergrund für den View
        self.backgroundColor = UIColor.clearColor()
    }

    required init?(coder aDecoder: NSCoder)
    {
        super.init(coder: aDecoder)
    }
    
    override func drawRect(rect: CGRect)
    {
        let context = UIGraphicsGetCurrentContext()
        
        // Die Linienstärke und die Farben setzen
        CGContextSetLineWidth(context, 2)
        CGContextSetStrokeColorWithColor(context, UIColor.blackColor().CGColor)
        CGContextSetFillColorWithColor(context, UIColor.yellowColor().CGColor)
        
        // Einen Pfad erstellen und ausfüllen
        self.createPath(context!)
        CGContextFillPath(context)
        
        // Einen Pfad erstellen und den Umriss zeichnen
        self.createPath(context!)
        CGContextStrokePath(context)
    }
    
    func createPath(context:CGContextRef)
    {
        let distanceFromBorder:CGFloat = 2
        let height = self.bounds.size.height
        let width = self.bounds.size.width
        let thirdHeight = height / 3
        let halfWidth = width / 2
        let halfHeight = height / 2
        
        CGContextBeginPath(context)
        CGContextMoveToPoint(context, width - distanceFromBorder, halfHeight)
        CGContextAddLineToPoint(context, halfWidth, distanceFromBorder)
        CGContextAddLineToPoint(context, halfWidth, thirdHeight)
        CGContextAddLineToPoint(context, distanceFromBorder, thirdHeight)
        CGContextAddLineToPoint(context, distanceFromBorder, thirdHeight * 2)
        CGContextAddLineToPoint(context, halfWidth, thirdHeight * 2)
        CGContextAddLineToPoint(context, halfWidth, height - distanceFromBorder)
        CGContextAddLineToPoint(context, width - distanceFromBorder, height / 2)
    }
    
    func handleRotationGesture(rotationRecognizer:UIRotationGestureRecognizer)
    {
        if rotationRecognizer.state == UIGestureRecognizerState.Changed ||
            rotationRecognizer.state == UIGestureRecognizerState.Ended
        {
            // Eine Rotation berechnen und zuweisen
            let transform = CGAffineTransformRotate(self.transform, rotationRecognizer.rotation)
            self.transform = transform
            
            // Die Rotation zurücksetzten
            rotationRecognizer.rotation = 0
        }
    }
    
    func handlePanGesture(panRecognizer:UIPanGestureRecognizer)
    {
        if panRecognizer.state == UIGestureRecognizerState.Changed ||
        panRecognizer.state == UIGestureRecognizerState.Ended
        {
            print("Pan")
            // Die Veränderung zur ursprünglichen 
            // Position ermitteln
            let translatedPoint = panRecognizer.translationInView(self.superview)
            // print("Veränderung X-Achse \(translatedPoint.x)")
            // print("Veränderung Y-Achse \(translatedPoint.y)")
            
            // Die aktuelle Position holen
            let center = self.center
            
            // Die neue Position berechnen
            let newPoint = CGPointMake(center.x + translatedPoint.x, center.y + translatedPoint.y)
            
            // Den View an der neuen Position zentrieren
            self.center = newPoint
            
            // Den Ursprung der 
            // Gestenerkennung zurücksetzen
            panRecognizer.setTranslation(CGPointZero, inView: self)
        }
    }
    
    func handlePinchGesture(pinchRecognizer:UIPinchGestureRecognizer)
    {
        if pinchRecognizer.state == UIGestureRecognizerState.Changed ||
            pinchRecognizer.state == UIGestureRecognizerState.Ended
        {
            print("Pinch")
            /*
            // Die Skalierung holen ...
            let scale = pinchRecognizer.scale
            // ... dem View zuweisen ...
            self.transform = CGAffineTransformScale(self.transform, scale, scale)
            // ... und die Skalierung zurücksetzen
            pinchRecognizer.scale = 1
            */
            
            // Die Skalierung holen ...
            let scale = pinchRecognizer.scale
            
            // Die neue Höhen und Breite berechnen und zuweisen
            var newBounds = self.bounds
            newBounds.size.height
              = self.bounds.size.height * scale
            newBounds.size.width
              = self.bounds.size.width * scale
            
            self.bounds = newBounds
            
            // Den View neu zeichnen
            self.setNeedsDisplay()
            
            // .Die Skalierung zurücksetzen
            pinchRecognizer.scale = 1
        }
    }
    
    func gestureRecognizer(gestureRecognizer: UIGestureRecognizer, shouldRecognizeSimultaneouslyWithGestureRecognizer otherGestureRecognizer: UIGestureRecognizer) -> Bool
    {
        return true
    }
    
    
}









