//
//  ViewController.swift
//  GesturePlayground
//
//  Created by Holger Hinzberg on 25.01.16.
//  Copyright © 2016 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
    }

    override func viewWillAppear(animated: Bool)
    {
        super.viewWillAppear(animated)
        
        let doubleTapRecognizer = UITapGestureRecognizer(target: self, action: "handleDoubleTapGesture:")
        doubleTapRecognizer.numberOfTapsRequired = 2
        self.view.addGestureRecognizer(doubleTapRecognizer)
        
        let tapRecognizer = UITapGestureRecognizer(target: self, action: "handleTapGesture:")
        tapRecognizer.numberOfTapsRequired = 1
        self.view.addGestureRecognizer(tapRecognizer)
        
        // Die Gestenerkennung erfolgt nicht,
        // wenn Double Tap erkannt wurde
        tapRecognizer.requireGestureRecognizerToFail(doubleTapRecognizer)
        
        let swipeRecognizer = UISwipeGestureRecognizer(target: self, action: "handleSwipeGesture:")
        swipeRecognizer.direction = UISwipeGestureRecognizerDirection.Down
        self.view.addGestureRecognizer(swipeRecognizer)
    }
    
    func handleSwipeGesture(swipeRecognizer:UISwipeGestureRecognizer)
    {
        for  subview in self.view.subviews
        {
            if subview.isKindOfClass(ArrowView)
            {
                subview.removeFromSuperview()
            }
        }
    }
    
    func handleDoubleTapGesture(tapRecognizer:UITapGestureRecognizer)
    {
        print("Double Tap")
    }
    
    func handleTapGesture(tapRecognizer:UITapGestureRecognizer)
    {
        // Die Position der Berührung ermitteln
        let location = tapRecognizer.locationInView(self.view)
        
        // Die Position für den Pfeil bestimmen - 
        // Höhe und Breite werden durch 2 geteilt,
        // um das Objekt zentriert unter dem 
        // Berühtungspunkt einzufügen
        let arrowHeight:CGFloat = 100
        let arrowWidth:CGFloat = 100
        let rect = CGRectMake(location.x - arrowWidth / 2, location.y - arrowHeight / 2, arrowWidth, arrowHeight)
        
        // Einen Arrow View erzeugen und einfügen
        let arrowView = ArrowView(frame: rect)
        self.view.addSubview(arrowView)
        
        // Dem Arrow View eine Gestenerkennung hinzufügen
        // Target es ebenfalls der das ArrowView-Objekt
        let panRecognizer = UIPanGestureRecognizer(target: arrowView, action: "handlePanGesture:")
        arrowView.addGestureRecognizer(panRecognizer)
        panRecognizer.delegate = arrowView
        
        let pinchRecognizer = UIPinchGestureRecognizer(target: arrowView, action: "handlePinchGesture:")
        arrowView.addGestureRecognizer(pinchRecognizer)
        pinchRecognizer.delegate = arrowView
        
        let rotationRecognizer = UIRotationGestureRecognizer(target: arrowView, action: "handleRotationGesture:")
        arrowView.addGestureRecognizer(rotationRecognizer)
        rotationRecognizer.delegate = arrowView
        
    }
    
    override func didReceiveMemoryWarning()
    {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    override func canBecomeFirstResponder() -> Bool
    {
        return true
    }
    
    override func motionEnded(motion: UIEventSubtype, withEvent event: UIEvent?)
    {
        if motion == UIEventSubtype.MotionShake
        {
            for  subview in self.view.subviews
            {
                if subview.isKindOfClass(ArrowView)
                {
                    subview.removeFromSuperview()
                }
            }
        }
    }
    

}

